=======
Credits
=======

This project has been originally forked from notipy the-isz/notipy

Development Lead
----------------

* Juan Manuel Schillaci <jmschillaci@gmail.com>

Contributors
------------

None yet. Why not be the first?
